import{x as s,ae as m,c as n,R as e,y as l,D as c,n as u,I as f}from"./index-CENm72M8.js";import{I as h}from"./ItemsListing-DD0YQzqP.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_3a9a25e3_lang-DHiiayJ-.js";import"./ProviderIcon.vue_vue_type_script_setup_true_lang-BU5cq-w_.js";import"./VListItem-DxGV844T.js";import"./VChip-Cj8S4-uh.js";import"./VList-D_s2On-E.js";import"./VCardText-DZgSKYwj.js";import"./VCard-BKOPmF8F.js";import"./VMenu-CEEm_N0n.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-Dli5DX_B.js";import"./VCheckbox-BkojC2td.js";import"./VCheckboxBtn-HMfKhzLE.js";import"./VTooltip-Cl46N3Te.js";import"./VSpacer-D9jJhlPb.js";/* empty css              */import"./PanelviewItemCompact-CvKHowIr.js";import"./Container-XgLzQRX2.js";import"./VContainer-BtbbAXeN.js";import"./Toolbar-B5avseYK.js";import"./VToolbar-CiZGbbCV.js";import"./VTextField-Bi_IoqdO.js";import"./VInfiniteScroll-xrzgbUmm.js";import"./layout-dXKdvoWL.js";import"./VRow-y-7npo4D.js";import"./VVirtualScroll-0_IQhuoN.js";import"./VAlert-DvTmx5J-.js";const Q=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),p=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),a=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":a,"sort-keys":["original","name","name_desc"],title:p.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{Q as default};
